// Global definitions and declarations for the "uAnt51"-Board 1V1
// (C) 2001 by Dipl.-Ing.(FH) Thorsten Godau DL9SEC

// INCLUDES =========================================================
#include "AT89S53.h"      // Definitions of registers, SFRs and Bits

// END INCLUDES =====================================================

// DEFINES ==========================================================
#define BEEPER    P1_2    // Pin where the beeper is connected
#define LCD_BL    P3_4    // Pin where the LCD backlight is connected
#define LED_OR    P3_4    // Pin where the orange LED is connected
#define LED_BL    P1_3    // Pin where the blue LED is connected

#define LCD_DATA  P2      // Dataport of LCD-Display (D4..D7)
#define LCD_RS    P2_2    // Register Select of LCD-Display
#define LCD_E     P2_3    // Enable of LCD-Display
#define LCD_RW    P3_5    // Read/Write of the LCD-Display
#define CTRL_REG  0       // Select instruction register
#define DATA_REG  1       // Select data register
#define BLINK     0x01    // Alias for blinking cursor
#define NOBLINK   0x00    // Alias for non blinking cursor
#define SHOW      0x02    // Alias for cursor on
#define HIDE      0x00    // Alias for cursor off
#define ON        0x04    // Alias for display on
#define OFF       0x00    // Alias for display off

#define SDA       P1_0    // I2C Data
#define SCL       P1_1    // I2C Clock

#define XIO_ID    0x40    // Device identifier of the I/O-Expander (PCF8574)
#define DPOT_ID   0x50    // Device identifier of the digital pot (DS1803)
#define ADDA_ID   0x90    // Device identifier of the AD/DA-converter (PCF8591)
#define RTC_ID    0xA0    // Device identifier of the Real Time Clock (PCF8583)
#define EEPROM_ID 0xA2    // Device identifier of the eeprom (M24C02)
#define READ      0x01    // Alias for read command bit
#define WRITE     0x00    // Alias for write command bit

#define ADCTRL    0x00    // ADC control byte
#define DACEN     0x40    // DAC enable mask

#define BSIZE     8       // Serial-buffer length
#define NCA       0x100   // Define value for "No Character Available"

// END DEFINES ======================================================


// Globals ==========================================================
volatile unsigned int DELAY;                    // Global delaytime

volatile idata unsigned char RXBuffer[BSIZE];   // Receivebuffer (BSIZE * 8 Bit)
volatile idata unsigned char TXBuffer[BSIZE];   // Transmitbuffer (BSIZE * 8 Bit)
volatile idata unsigned char RXB;               // Begin pointer for serial buffer
volatile idata unsigned char RXE;               // End pointer for serial buffer
volatile idata unsigned char TXCNT;             // TXBuffer counter
volatile idata unsigned char TXPOS;             // TXBuffer position
volatile idata unsigned char BUSY;              // TX-Interrupt-Busy-Flag

// Table to select LCD DD-RAM address (including instruction and address)
// Usable for 16 x 1-, 2- or 4-line display.
// 0x00..0x0F -> Line 1
// 0x40..0x4F -> Line 2
// 0x10..0x1F -> Line 3
// 0x50..0x5F -> Line 4
// Modify this array for other LCD sizes (e.g. 8 x 1, 32 x 2...)
// by adding 0x80 to any displayable LCD DD-RAM adress.
// C-Flash memory can saved by reducing the array to minimum requirements.

unsigned char code LOCATION[4][16] = { {0x80,0x81,0x82,0x83,0x84,0x85,0x86,0x87,
                                        0x88,0x89,0x8A,0x8B,0x8C,0x8D,0x8E,0x8F},
                                       {0xC0,0xC1,0xC2,0xC3,0xC4,0xC5,0xC6,0xC7,
                                        0xC8,0xC9,0xCA,0xCB,0xCC,0xCD,0xCE,0xCF},
                                       {0x90,0x91,0x92,0x93,0x94,0x95,0x96,0x97,
                                        0x98,0x99,0x9A,0x9B,0x9C,0x9D,0x9E,0x9F},
                                       {0xD0,0xD1,0xD2,0xD3,0xD4,0xD5,0xD6,0xD7,
                                        0xD8,0xD9,0xDA,0xDB,0xDC,0xDD,0xDE,0xDF} };

// Characterpattern for the 8 customizable LCD-characters at adress 0x00..0x07
// Every array-line represents a 5x8 character (b0..b4 are the usable dots,
// b5..b7 are always 0. Example for a "heart"-symbol at adress 0x00:
//
// Bit         43210    
// Top line    ::::: -> CUSTOM[0] = 0x00
//             :#:#: -> CUSTOM[1] = 0x0A
//             ##### -> CUSTOM[2] = 0x1F
//             ##### -> CUSTOM[3] = 0x1F
//             :###: -> CUSTOM[4] = 0x0E
//             ::#:: -> CUSTOM[5] = 0x04
//             ::::: -> CUSTOM[6] = 0x00
// Bottom line ::::: -> CUSTOM[7] = 0x00 (this line is used by the cursor!)
//
unsigned char code CUSTOM[64] = { 0x00,0x0A,0x1F,0x1F,0x0E,0x04,0x00,0x00,    // 1. character at adr 0 (heart)
                                  0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,    // 2. character at adr 1
                                  0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,    // 3. character at adr 2
                                  0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,    // 4. character at adr 3
                                  0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,    // 5. character at adr 4
                                  0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,    // 6. character at adr 5
                                  0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,    // 7. character at adr 6
                                  0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00 };  // 8. character at adr 7


// Structure for time/date storage
volatile struct TIME_T { unsigned char tm_sec;  // TM.tm_sec  : seconds      0..59
                         unsigned char tm_min;  // TM.tm_min  : minutes      0..59
                         unsigned char tm_hour; // TM.tm_hour : hours        0..23
                         unsigned char tm_dom;  // TM.tm_dom  : day of month 1..31
                         unsigned char tm_mon;  // TM.tm_mon  : month        1..12
                         unsigned char tm_year; // TM.tm_year : year         0..3
                         unsigned char tm_dow;  // TM.tm_dow  : day of week  0..6
                        } TM;
                        
// Enumerations of the weekdays (monday = 0)
enum {monday, tuesday, wednesday, thursday , friday, saturday, sunday};
enum {Montag, Dienstag , Mittwoch, Donnerstag, Freitag, Samstag, Sonntag};


// END Globals ======================================================